debianHELP | Militantly FREE software support.

Skip to main content

## Recent Forum Activity

Subject | Replies | Author | Time
--- | --- | --- | ---
Debian Project News - December 1, 2014 | 1 | srsjerry187 | 1 day 5 hours ago
New user help and advice | 2 | srsjerry187 | 3 days 4 hours ago
MD disk in Sony VPCZ laptops | 0 | ricardt | 6 days 5 hours ago
sudo dpkg-reconfigure tzdata Wrong Time for Amererica/Caracas | 1 | jesusguevarauto... | 2 weeks 5 days ago
HP 6530b laptop won't mount Windoze 7 partition anymore | 0 | joe52 | 2 weeks 5 days ago
Debian Project News - November 14, 2014 | 0 | IntnsRed | 2 weeks 6 days ago
Desktop distorted in all but Gnome Classic | 0 | krepitus | 4 weeks 8 hours ago
minidlna does not strart at boot time | 3 | pythagoras | 4 weeks 1 day ago
Install lvm2 - errors | 1 | sa_cooke | 1 month 1 day ago
Reinstalling Nouveau drivers after Nvidia proprietary [Debian Jessie] | 0 | 1 | 1 month 3 days ago

## Pages

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8
- 9
- …
- next ›
- last »

# Debian Project News - December 1, 2014

## Forums:

- Debian News

------------------------------------------------------------------------
The Debian Project https://www.debian.org/
Debian Project News debi...@lists.debian.org
December 1, 2014 https://www.debian.org/News/weekly/2014/16/
------------------------------------------------------------------------

Welcome to this year's sixteenth issue of DPN, the newsletter for the Debian community. Topics covered in this issue include:

* DebConf15 welcomes its first eleven sponsors!
* Debian running on a graphing calculator
* Votes on the General Resolution on init system coupling
* Bits from the Debian Med team
* Freexians third report about Debian Long Term Support
* Newcomer tag in BTS
* FOSS Outreach program for women
* Release Team Sprint Results
* Fun and Sanity in Debian
* Notes on the Cambridge Mini-DebConf
* DebConf14 final report
* Debian Description Translation Project
* How to get new packages into stable
* LiMux Munich Bug Squashing Party
* DPN asks: Hams, What do you do?
* Other news
* New Debian Contributors
* Release-Critical bugs statistics for the upcoming release
* Important Debian Security Advisories
* New and noteworthy packages
* Work-needing packages
* Want to continue reading DPN?

# Debian Project News - November 14, 2014

## Forums:

- Debian News

------------------------------------------------------------------------
The Debian Project https://www.debian.org/
Debian Project News debi...@lists.debian.org
November 14, 2014 https://www.debian.org/News/weekly/2014/15/
------------------------------------------------------------------------

Welcome to this year's fifteen issue of DPN, the newsletter for the Debian community. Topics covered in this issue include:

* The Debian Community combats Global Warming with a Freeze
* Tokyo area Debian study group
* First Jessie based Debian Edu released
* LTS Reports for October 2014
* Other Reports
* Open Source Conference 2014 Tokyo/Fall
* Who's using Debian Audit
* Jessie removals/updates
* 2014 Mini-DebConf in Cambridge at ARM
* New Debian Contributors
* Release-Critical bugs statistics for the upcoming release
* Important Debian Security Advisories
* New and noteworthy packages
* Work-needing packages
* Want to continue reading DPN?

# Debian Project News - October 27, 2014

## Forums:

- Debian News

------------------------------------------------------------------------
The Debian Project https://www.debian.org/
Debian Project News debi...@lists.debian.org
October 27, 2014 https://www.debian.org/News/weekly/2014/14/
------------------------------------------------------------------------

Welcome to this year's fourteenth issue of DPN, the newsletter for the Debian community. Topics covered in this issue include:

* Debian & Stuff podcast
* Debian switching back to GNOME as the default desktop
* Contributing to Debian in other ways
* The Ada initiative and the Outreach Program For Women
* Who is 15?!
* Squeeze long term support reports
* General Resolution: init system coupling
* Bits from the Debian Multimedia Maintainers
* Debian Quiz Game, help wanted!
* Debian DebUtsav'14
* Other reports
* Upcoming events
* New Debian Contributors
* Release-Critical bugs statistics for the upcoming release
* Important Debian Security Advisories
* New and noteworthy packages
* Work-needing packages
* Want to continue reading DPN?

# Debian Project mourns the loss of Peter Miller

## Forums:

- Debian News

------------------------------------------------------------------------
The Debian Project https://www.debian.org/
Debian Project mourns the loss of Peter Miller pre...@debian.org
October 20th, 2014 https://www.debian.org/News/2014/20141020
------------------------------------------------------------------------

The Debian Project recently learned that it has lost a member of its community. Peter Miller died on July 27th after a long battle with leukemia.

# Debian Project chooses LeaseWeb to provide global snapshot archive

## Forums:

- Debian News

------------------------------------------------------------------------
The Debian Project https://www.debian.org/
Debian Project chooses LeaseWeb to provide global snapshot archive
pre...@debian.org
October 14th, 2014 https://www.debian.org/News/2014/20141014
------------------------------------------------------------------------

The Debian Project, provider of one of the earliest OS distributions in Linux’s history, has chosen LeaseWeb Netherlands, part of global hosting brand LeaseWeb, to deploy and host their globally available Debian OS Snapshot Archive with 80 Terabyte (TB) of capacity and ample room to grow.

The Debian OS Snapshot Archive, available at http://snapshot.debian.org, allows access to old software packages accepted into Debian since the operating system's first release over twenty years ago. The snapshot archive provides developers with access to an immense amount of historical information regarding Debian packages, enabling software development including debugging and patching.

The Debian snapshot archive is growing year-on-year, currently expanding at a rate of more than 5 TB per year. As a result, The Debian Project needed a hosting partner that could support its worldwide infrastructure needs.

## Pages

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8
- 9
- …
- next ›
- last »

## Latest Content Comments

Subject | Author | Time
--- | --- | ---
Re: a good download manager for debian wheezy | linuxdiabolo | 9 months 3 weeks ago
... screensaver off ... | linuxdiabolo | 9 months 3 weeks ago
Re: a good download manager for debian wheezy | IntnsRed | 1 year 3 months ago

## Pages

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8
- 9
- …
- next ›
- last »

## Newest Content

Subject | Type | Comments | Time
--- | --- | --- | ---
Linux Foundation to Build Massive Open Online Course Program with edX | Story | 0 | 9 months 1 day ago
How-to Create a Highly Anonymous Proxy Server from a Default Debian Squid3 Setup | Book page | 0 | 9 months 1 week ago
The Debian Administrator's Handbook: Updated for Wheezy | Story | 0 | 10 months 2 weeks ago
The way automation typically works out. :-) | Story | 0 | 10 months 2 weeks ago
Installing Debian testing On GPT HDDs (> 2TB) From A Grml Live Linux | Story | 0 | 1 year 1 week ago
Running ownCloud 5.0 On Nginx (LEMP) On Debian Wheezy | Story | 0 | 1 year 2 weeks ago
Using RoundCube Webmail With ISPConfig 3 On Debian Wheezy (nginx) | Story | 0 | 1 year 1 month ago
High-Availability Storage With GlusterFS 3.2.x On Debian Wheezy | Story | 0 | 1 year 2 months ago
a good download manager for debian wheezy | Blog entry | 2 | 1 year 3 months ago
how can i stop the backlight from going off or the screen saver from coming on while watching a movie on vlc | Blog entry | 2 | 1 year 3 months ago

## Pages

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8
- 9
- …
- next ›
- last »

## Useful Debian Links

• Debian Weekly News - Essential reading for any Debian fan. • Documentation - Debian's own docs, including installation docs. • FAQ - Got questions about Debian GNU/Linux? • Security - Security information and alerts! • Bug System - Bug tracking and instructions on reporting bugs. • CD Images - Where/how to get Debian GNU/Linux CD images. • Debian Weather • Mailing List Subscription - Dozens of Debian-specific support mailing lists! • Mailing List Archives - Searchable archives of Debian's mailing lists. • Free Software Guidelines - Learn Debian's idea of what "free" software really is. • Package Listings - A very valuable tool: searchable, integrated with bug reports. • Apt-Get Sources - Sources for *.debs which are not official Debian packages. • Backports - Unofficial new software packages that have been "back-ported" to work with the Debian stable/official release. • Developer's Corner - Info about the people behind Debian, policies, and how to package *.deb files.

## Debian Security Advisories+

- DSA-3090 iceweasel - security update
- DSA-3089 jasper - security update
- DSA-3088 qemu-kvm - security update
- DSA-3087 qemu - security update
- DSA-3086 tcpdump - security update

More

## EFF's Deeplinks

- Appeals Court to Hear Oral Arguments in Idaho Woman's Case Against NSA Spying
- Pyrawebs: Paraguayans Rise Up Against Mandatory Data Retention
- Sifting Fact from Fiction with All Writs and Encryption: No Backdoors
- Can’t Get Public Approval to Buy a Drone? Do it in Private!
- Copyright Law as a Tool for State Censorship of the Internet

More

## GNU/Linux

- Feds dig up law from 1789 to demand Apple, Google decrypt smartphones, slabs
- Joytone interview
- HP Steps Up Big Data Game with Cloud-Based Helion Offering
- Ubuntu 14.10 PXE server installation
- Google Code-in tasks and rewards for teens

More

## Debian Weekly News

- DebConf15 welcomes its first eleven sponsors!
- Debian running on a graphing calculator
- Votes on the General Resolution on init system coupling
- Bits from the Debian Med team
- The newsletter for the Debian community

More

## Geek Stuff

- Ofcom Will Remove Mandatory Ham Callsign ID Interval, Allow Encryption For Some
- Make a Kids' Power Wheel Toy Awesome for $500 (Video)
- Should IT Professionals Be Exempt From Overtime Regulations?
- Nanotube Film Could Replace Defective Retinas
- In North Korea, Hackers Are a Handpicked, Pampered Elite

More

## Liliputing

- Microsoft Torque brings Bing voice search to Android phones
- Deals of the Day (12-05-2014)
- Raccoon Google Play desktop client lets you download APK files
- Report: Sony to launch Android TV products in early 2015
- Microsoft’s Cortana voice assistant now speaker 6 languages

More

## General News

- The diplomat’s portable handbook (wheelbarrow required)
- Call for surveillance laws overhaul
- Text reminders 'stop medicine waste'
- 'Arctic' blast, snow joke - front pages
- Uruguay to take Guantanamo prisoners

More

## Socialism OnLine!

- Inside Big Oil’s ‘Conspiracy’ to Kill West Coast Climate Laws
- Marijuana news: Washington school district rejects $14,000 donation from pot farmer
- In US-Supported Egypt, 188 Protesters Are Sentenced to Die Days After Mubarak is Effectively Freed
- Are Humans Going Extinct?
- Chris Hedges: The Truth About Freedom Of The Press

More